@@ -24,10 +24,11 @@
 #include "recurrence.h"
 #include "sortablelist.h"
 
+
 #include "kcalcore_debug.h"
 
-#include <QtCore/QBitArray>
-#include <QtCore/QTime>
+#include <QBitArray>
+#include <QTime>
 
 using namespace KCalCore;
 
@@ -167,9 +168,7 @@ void Recurrence::addObserver(RecurrenceObserver *observer)
 
 void Recurrence::removeObserver(RecurrenceObserver *observer)
 {
-    if (d->mObservers.contains(observer)) {
-        d->mObservers.removeAll(observer);
-    }
+    d->mObservers.removeAll(observer);
 }
 
 KDateTime Recurrence::startDateTime() const
@@ -202,7 +201,7 @@ RecurrenceRule *Recurrence::defaultRRule(bool create) const
 {
     if (d->mRRules.isEmpty()) {
         if (!create || d->mRecurReadOnly) {
-            return 0;
+            return nullptr;
         }
         RecurrenceRule *rrule = new RecurrenceRule();
         rrule->setStartDt(startDateTime());
@@ -215,7 +214,7 @@ RecurrenceRule *Recurrence::defaultRRule(bool create) const
 
 RecurrenceRule *Recurrence::defaultRRuleConst() const
 {
-    return d->mRRules.isEmpty() ? 0 : d->mRRules[0];
+    return d->mRRules.isEmpty() ? nullptr : d->mRRules[0];
 }
 
 void Recurrence::updated()
@@ -707,12 +706,12 @@ QList<RecurrenceRule::WDayPos> Recurrence::yearPositions() const
 RecurrenceRule *Recurrence::setNewRecurrenceType(RecurrenceRule::PeriodType type, int freq)
 {
     if (d->mRecurReadOnly || freq <= 0) {
-        return 0;
+        return nullptr;
     }
 
     // Ignore the call if nothing has change
     if (defaultRRuleConst() && defaultRRuleConst()->recurrenceType() == type && frequency() == freq) {
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     qDeleteAll(d->mRRules);
@@ -720,7 +719,7 @@ RecurrenceRule *Recurrence::setNewRecurrenceType(RecurrenceRule::PeriodType type
     updated();
     RecurrenceRule *rrule = defaultRRule(true);
     if (!rrule) {
-        return 0;
+        return nullptr;
     }
     rrule->setRecurrenceType(type);
     rrule->setFrequency(freq);
@@ -945,7 +944,7 @@ void Recurrence::addYearlyPos(short pos, const QBitArray &days)
     addMonthlyPos(pos, days);
 }
 
-void Recurrence::setYearlyPos(QList<RecurrenceRule::WDayPos> &days)
+void Recurrence::setYearlyPos(const QList<RecurrenceRule::WDayPos> &days)
 {
     setMonthlyPos(days);
 }
@@ -1524,11 +1523,11 @@ KCALCORE_EXPORT QDataStream &KCalCore::operator<<(QDataStream &out, KCalCore::Re
         << r->d->mAllDay << r->d->mRecurReadOnly << r->d->mExDates
         << r->d->mExRules.count() << r->d->mRRules.count();
 
-    foreach (RecurrenceRule *rule, r->d->mExRules) {
+    for (RecurrenceRule *rule : qAsConst(r->d->mExRules)) {
         out << rule;
     }
 
-    foreach (RecurrenceRule *rule, r->d->mRRules) {
+    for (RecurrenceRule *rule : qAsConst(r->d->mRRules)) {
         out << rule;
     }
 
