@@ -522,7 +522,7 @@ public:
      */
     void addYearlyPos(short pos, const QBitArray &days);
 
-    void setYearlyPos(QList<RecurrenceRule::WDayPos> &days);
+    void setYearlyPos(const QList<RecurrenceRule::WDayPos> &days);
 
     /** Returns the day numbers within a yearly recurrence.
      * @return the days of the year for the event. E.g. if the list contains
@@ -650,7 +650,7 @@ public:
     */
     void removeObserver(RecurrenceObserver *observer);
 
-    void recurrenceChanged(RecurrenceRule *) Q_DECL_OVERRIDE;
+    void recurrenceChanged(RecurrenceRule *) override;
 
 protected:
     RecurrenceRule *setNewRecurrenceType(RecurrenceRule::PeriodType type, int freq);
